summaryrefslogtreecommitdiff
path: root/ArmPkg/Include
diff options
context:
space:
mode:
Diffstat (limited to 'ArmPkg/Include')
-rw-r--r--ArmPkg/Include/Library/ArmGicLib.h10
1 files changed, 9 insertions, 1 deletions
diff --git a/ArmPkg/Include/Library/ArmGicLib.h b/ArmPkg/Include/Library/ArmGicLib.h
index 78bba23ba7..66e12dad59 100644
--- a/ArmPkg/Include/Library/ArmGicLib.h
+++ b/ArmPkg/Include/Library/ArmGicLib.h
@@ -72,7 +72,7 @@
//
// GIC SEC interfaces
//
VOID
EFIAPI
@@ -83,6 +83,14 @@ ArmGicSetupNonSecure (
VOID
EFIAPI
+ArmGicSetSecureInterrupts (
+ IN UINTN GicDistributorBase,
+ IN UINTN* GicSecureInterruptMask,
+ IN UINTN GicSecureInterruptMaskSize
+ );
+
+VOID
+EFIAPI
ArmGicEnableInterruptInterface (
IN INTN GicInterruptInterfaceBase
);
@@ -72,7 +72,7 @@
//
-// GIC SEC interfaces
+// GIC Secure interfaces
//
VOID